translate.storage.tbx.tbxfile

Package translate :: Package storage :: Module tbx :: Class tbxfile |
[hide private]
[frames] | no frames]

# Class tbxfile

source code

Class representing a TBX file store.

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
addheader(self) Initialise headers with TBX specific things. | source code
Inherited from `lisa.LISAfile`: `__init__`, `__str__`, `addsourceunit`, `addunit`, `initbody`, `namespaced`, `parse` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("TBX Glossary")` The human usable name of this store type
| Mimetypes = `["application/x-tbx"]` A list of MIME types associated with this store type
| Extensions = `["tbx"]` A list of file extentions associated with this store type
| rootNode = `"martif"`
| bodyNode = `"body"`
| XMLskeleton = `'''<?xml version="1.0`...``
Inherited from `lisa.LISAfile`: `namespace` Inherited from `base.TranslationStore`: `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### addheader(self) | source code
Initialise headers with TBX specific things. Overrides: lisa.LISAfile.addheader

Class Variable Details | [hide private]

  ### XMLskeleton Value:
      '''<?xml version="1.0"?>
      <!DOCTYPE martif PUBLIC "ISO 12200:1999A//DTD MARTIF core (DXFcdV04)//
      EN" "TBXcdv04.dtd">
      <martif type="TBX">
      <martifHeader>
      <fileDesc>
      <sourceDesc><p>Translate Toolkit</p></sourceDesc>
      </fileDesc>
      ...